@@ -25,7 +25,7 @@
 #include "netstatus-icon.h"
 
 #include <gtk/gtk.h>
-#include <libgnome/gnome-i18n.h>
+#include <glib/gi18n.h>
 
 #include "netstatus-util.h"
 #include "netstatus-enums.h"
@@ -61,8 +61,6 @@ struct _NetstatusIconPrivate
   GtkOrientation  orientation;
   int             size;
 
-  GtkTooltips    *tooltips;
-
   gulong          state_changed_id;
   gulong          name_changed_id;
   gulong          wireless_changed_id;
@@ -378,7 +376,10 @@ netstatus_icon_name_changed (NetstatusIface *iface,
   iface_name = netstatus_iface_get_name (icon->priv->iface);
   if (iface_name)
     {
-      freeme = g_strdup_printf (_("Network Connection: %s"), iface_name);
+      const char *state_string;
+
+      state_string = netstatus_get_state_string (icon->priv->state);
+      freeme = g_strdup_printf (_("Network Connection: %s\n%s"), iface_name, state_string);
       tip = freeme;
     }
   else
@@ -386,7 +387,7 @@ netstatus_icon_name_changed (NetstatusIface *iface,
       tip = _("Network Connection");
     }
 
-  gtk_tooltips_set_tip (icon->priv->tooltips, GTK_WIDGET (icon), tip, NULL);
+  gtk_widget_set_tooltip_text (GTK_WIDGET (icon), tip);
 
   g_free (freeme);
 }
@@ -407,6 +408,7 @@ netstatus_icon_state_changed (NetstatusIface *iface,
       icon->priv->state = state;
 
       netstatus_icon_update_image (icon);
+      netstatus_icon_name_changed (icon->priv->iface, NULL, icon);
     }
 }
 
@@ -475,10 +477,6 @@ netstatus_icon_destroy (GtkObject *widget)
   icon->priv->wireless_changed_id = 0;
   icon->priv->signal_changed_id   = 0;
 
-  if (icon->priv->tooltips)
-    g_object_unref (icon->priv->tooltips);
-  icon->priv->tooltips = NULL;
-  
   icon->priv->image = NULL;
 
   GTK_OBJECT_CLASS (parent_class)->destroy (widget);
@@ -528,13 +526,13 @@ scale_pixbuf (GdkPixbuf      *pixbuf,
 	{
 	  if (orientation == GTK_ORIENTATION_HORIZONTAL)
 	    {
-	      scaled_width  = orig_width;
+	      scaled_width  = orig_width * scale;
 	      scaled_height = orig_height * scale;
 	    }
 	  else /* if (orientation == GTK_ORIENTATION_VERTICAL) */
 	    {
 	      scaled_width  = orig_width * scale;
-	      scaled_height = orig_height;
+	      scaled_height = orig_height * scale;
 	    }
 	}
 
@@ -584,7 +582,7 @@ netstatus_icon_scale_icons (NetstatusIcon  *icon,
 static inline GObjectClass *
 get_box_class (GtkOrientation orientation)
 {
-  return gtk_type_class (orientation == GTK_ORIENTATION_HORIZONTAL ? GTK_TYPE_HBOX : GTK_TYPE_VBOX);
+  return g_type_class_ref (orientation == GTK_ORIENTATION_HORIZONTAL ? GTK_TYPE_HBOX : GTK_TYPE_VBOX);
 }
 
 static void
@@ -870,10 +868,6 @@ netstatus_icon_instance_init (NetstatusIcon      *icon,
   gtk_container_add (GTK_CONTAINER (icon), icon->priv->signal_image);
   gtk_widget_hide (icon->priv->signal_image);
 
-  icon->priv->tooltips = gtk_tooltips_new ();
-  g_object_ref (icon->priv->tooltips);
-  gtk_object_sink (GTK_OBJECT (icon->priv->tooltips));
-
   gtk_widget_add_events (GTK_WIDGET (icon),
 			 GDK_BUTTON_PRESS_MASK | GDK_ENTER_NOTIFY_MASK | GDK_LEAVE_NOTIFY_MASK);
 }
@@ -1062,10 +1056,7 @@ netstatus_icon_set_tooltips_enabled (NetstatusIcon *icon,
     {
       icon->priv->tooltips_enabled = enabled;
 
-      if (enabled)
-	gtk_tooltips_enable (icon->priv->tooltips);
-      else
-	gtk_tooltips_disable (icon->priv->tooltips);
+      gtk_widget_set_has_tooltip (GTK_WIDGET (icon), enabled);
 
       g_object_notify (G_OBJECT (icon), "tooltips-enabled");
     }
